import { useEffect, useRef, useState } from "react"
import { API_URL } from "../../config"

const useAddAnnouncement = () => {
    const [status, setStatus] = useState("Опубликовать")

    const timerIdRef = useRef()
    const abortControllerRef = useRef()

    const doAdd = async (formData) => {
        if (status === "Загрузка") {
            abortControllerRef.current?.abort()
            setStatus("Отменено")
            timerIdRef.current = setTimeout(() => setStatus("Опубликовать"), 3000)
            return
        }

        setStatus("Загрузка")

        const abortController = new AbortController()
        abortControllerRef.current = abortController

        try {
            const res = await fetch(API_URL + "/announcement", {
                method: 'PUT',
                body: formData,
                signal: abortController.signal
            })

            const data = await res.json()

            if (!data.Answer) {
                throw new Error("Не удалось опубликовать объявление")
            }
            setStatus("Опубликовано")

        } catch (err) {
            setStatus(err.message ?? err)
            timerIdRef.current = setTimeout(() => setStatus("Опубликовать"), 10000)
        }
    }

    useEffect(() => {
        const abortController = abortControllerRef.current
        return () => {
            clearTimeout(timerIdRef.current)
            abortController?.abort()
        }
    })

    return {doAdd, status}
}

export default useAddAnnouncement